%{!?kernel_version: %{expand: %%define kernel_version %(uname -r| perl -pe 's/-[a-zA-Z].*?$//g')}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %%define type %(uname -r| perl -pe 's/.*-//g')}}

%define releasetag %{kversionreltag}.%{type}
%define kernel_dir %{kernel_version}-%{type}
%define kmp_version %version

# Keep the modKey def identical to that in util.sh-PMWV.*
%define modKey 'PMWV|%{type}|vmxnet3'
%define vmwDB /usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-db.pl --os=linux,sle,9
%define vmwPMWV /usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-pmwv.pl --os=linux,sle,9 --release=%{kernel_dir} --build 2211464 --modKey %{modKey}

Name:         vmware-tools-vmxnet3
BuildRequires: kernel-source kernel-syms
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vmxnet3 kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.0.0.32
Release:      4.sles9
BuildRoot:    %{_tmppath}/%{name}-%{version}-build
Source1:      vmxnet3-configModule.tar.gz

Source0:      vmxnet3.tar

%prep
%setup -n vmxnet3-only

%build
make clean
make

# NOTE: RHEL 4 has MODVERSIONS enabled but does not generate the module.symvers
#       file we would need in order to properly propagate symbol versions
#       in-between interdependent kernel modules.  See bug 568405 for more info.
if [ "vmxnet3" = "vsock" -o "vmxnet3" = "vmhgfs" ]; then
   echo
   echo
   echo "Please ignore the \"VMCI_ ... undefined!\" warnings generated by the build system."
   echo "The vmxnet3 module will load and function properly despite those warnings."
   echo
   echo
fi

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
install -m 644 -D ../vmxnet3.o $RPM_BUILD_ROOT/lib/modules/%{kernel_dir}/extra/vmware/vmxnet3.ko
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vmxnet3.  The vmxnet3 kernel module allows for enhanced network performance on the vmxnet3 virtual network device.

%package common
Summary:      Contains the common files used by all the vmxnet3 kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.0
Release:      4.sles9
Version:      8.6.14

%description common
 This package contains the common system configuration and scripts responsible for loading the vmxnet3 kernel module.  The vmxnet3 kernel module allows for enhanced network performance on the vmxnet3 virtual network device.

%package kmp-%{type}
Summary:      The vmxnet3 kernel module built for the %{kernel_version} kernel.
Group:        System/Kernel
Requires:     vmware-tools-vmxnet3-common
Requires:     vmware-tools-foundation >= 0:8.6.0
Provides:     vmware-tools-vmxnet3-kmp
Release:      %{kversionreltag}.4.sles9


%description kmp-%{type}
 This package contains a pre-compiled vmxnet3 module for use with the %{kernel_version} kernel.   The vmxnet3 kernel module allows for enhanced network performance on the vmxnet3 virtual network device.

%pre kmp-%{type}
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   kmodType=`uname -r | sed -e 's/.*-//g'`
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmxnet3 stop
   fi

   %{vmwPMWV} --rpmSection=Postun
fi

# Configure
%{vmwPMWV} --rpmSection=Pre

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmxnet3 ]; then
      /sbin/insserv -r vmxnet3 /dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-deconfig.pl --os=linux,sle,9 --toDeconfigure=vmxnet3
   /usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-db.pl --os=linux,sle,9 --dbDelAnswer VMXNET3_NAME
fi

# Configure
/usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-db.pl --os=linux,sle,9 --dbAddAnswer VMXNET3_NAME,vmxnet3
/usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-config.pl --os=linux,sle,9 --toConfigure=vmxnet3
if [ -e /etc/init.d/vmxnet3 ]; then
   /sbin/insserv -f vmxnet3 >/dev/null 2>&1
fi

%post kmp-%{type}
# Configure
# Invoke the PMWV Post Section
%{vmwPMWV} --rpmSection=Post --baseMod=/lib/modules/%{kernel_dir}/extra/vmware/vmxnet3.ko

# If the type matches, start the init script
kmodType=`uname -r | sed -e 's/.*-//g'`
if [ "$kmodType" = "%{type}" ]; then
   /etc/init.d/vmxnet3 start
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vmxnet3 ]; then
      /sbin/insserv -r vmxnet3 /dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-deconfig.pl --os=linux,sle,9 --toDeconfigure=vmxnet3
   /usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-db.pl --os=linux,sle,9 --dbDelAnswer VMXNET3_NAME
fi

%preun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   kmodType=`uname -r | sed -e 's/.*-//g'`
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmxnet3 stop
   fi
fi

%postun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   %{vmwPMWV} --rpmSection=Postun
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-config.pl
/etc/init.d/vmxnet3

%files kmp-%{type}
%defattr(-, root, root, -)
/lib/modules/%{kernel_dir}/extra/vmware/vmxnet3.ko
